/*
 * Class:   GoogleSearchIview
 *
 * Date:    2002-11-07
 * Copyright: Gregor Wolf <gregor.wolf@chiemgau.com>
 *
 */


import com.sapportals.htmlb.*;
import com.sapportals.htmlb.enum.GroupDesign;
import com.sapportals.htmlb.enum.TextViewDesign;
import com.sapportals.htmlb.event.Event;
import com.sapportals.htmlb.page.DynPage;
import com.sapportals.htmlb.page.PageException;
import com.sapportals.portal.htmlb.page.PageProcessorComponent;
import com.sapportals.portal.prt.component.IPortalComponentProfile;
import com.sapportals.portal.prt.component.IPortalComponentRequest;
import java.io.*;
import com.google.soap.search.*;

public class GoogleSearchIview extends PageProcessorComponent {

    // ------------------------------------------------------------------------
    // --- method                                                           ---
    // ------------------------------------------------------------------------
    public DynPage getPage() {
        return new MyDynPage();
    }


    // ************************************************************************
    // *** inner class                                                      ***
    // ************************************************************************
    public static class MyDynPage extends DynPage {
        // ------------------------------------------------------------------------
        // --- field                                                            ---
        // ------------------------------------------------------------------------
        private String query;
        // ------------------------------------------------------------------------
        // --- methods                                                          ---
        // ------------------------------------------------------------------------
        /**
         * used for user initialization of the user. Only first time (once).
         */
        public void doInitialization() {
        }
        /**
         * used for handling the input. In general called at second time.
         */
        public void doProcessAfterInput() throws PageException {
        }
        /**
         * used for handling the output. This method is always called.
         * In this example there is only the Hello World output.
         */
        public void doProcessBeforeOutput() throws PageException {
		String url;
		String title;
		String queryString = "";
		String resultString = "";
		// get the request
		IPortalComponentRequest request = (IPortalComponentRequest) this.getRequest();
		// get the profile
		IPortalComponentProfile profile = request.getComponentContext().getProfile();
		// read the values out of the profiles file
		String clientKey = profile.getProperty("key");
		String helloString = profile.getProperty("HelloString");
		String groupTitle = profile.getProperty("GroupTitle");
		String groupTooltip = profile.getProperty("GroupTooltip");
		// Create a Google Search object, set our authorization key
		GoogleSearch s = new GoogleSearch();
		s.setKey(clientKey);
		if (this.query != null) {
			// building a new helloString
			queryString = "Ihre Anfrage: " + this.query;
			// Depending on user input, do search or cache query, then print out result
			try {
				s.setQueryString(this.query);
				GoogleSearchResult r = s.doSearch();
				// resultString = r.toString();
				GoogleSearchResultElement results[] = r.getResultElements();
				int j;
				for (j=0; j<results.length; j++) {
				    url = results[j].getURL();
				    if (results[j].getTitle().equals(""))
					title = url;
				    else
					title = results[j].getTitle();
			    
				    resultString = resultString + "<a href=\"" + url + "\">" + title + "</a><br>";
				}
			} catch (GoogleSearchFault f) {
				resultString = "The call to the Google Web APIs failed:";
				resultString = queryString + f.toString();
			}
		}
		Form myForm = this.getForm(); // get the form from DynPage
                Group myGroup = new Group(); // create a Group component
                myGroup.setDesign(GroupDesign.SAPCOLOR);
                myGroup.setTitle(groupTitle);
                myGroup.setTooltip(groupTooltip);
                myGroup.setWidth("300 px");
                TextView myText = new TextView(); // set the TextView
                myText.setText(queryString);
                myText.setDesign(TextViewDesign.HEADER3);
                TextView myLabel = new TextView(); // set the TextView
                myLabel.setDesign(TextViewDesign.LABEL);
                myLabel.setText("Suchanfrage:");
		InputField myInput = new InputField("q"); // create the input field
                myInput.setTooltip("Geben Sie Ihre Suchanfrage ein.");
		myInput.setValue(this.query);
                myInput.setWidth("150 px");
                Button myButton = new Button("submitButton"); // create the button
                myButton.setOnClick("sendName");
                myButton.setText("Suchen");
                myButton.setTooltip("Klicken Sie, um die Suchanfrage abzusenden");
                TextView mySearchResult = new TextView(); // set the TextView
                mySearchResult.setDesign(TextViewDesign.STANDARD);
                mySearchResult.setText(resultString);
		GridLayout myGrid = new GridLayout(); // create grid layout for design
                myGrid.addComponent(1, 1, myLabel); // set myLabel to pos 1,1
                myGrid.addComponent(1, 2, myInput); // Input field right beside
                myGrid.addComponent(2, 2, myButton); // Button direct under the input field
		myGrid.addColSpanText(3, 1, resultString, 2); // Search Result in the next line left
    	    
                myGroup.addComponent(myText); // add myText to myGroup
                myGroup.addComponent(myGrid); // add myGrid to myGroup
                myForm.addComponent(myGroup); // add myGroup to the Form
        }
        /**
         * will be called by the Button. The event can be handled inside this method.
         *  
         * @param myName the event which was caught
         */
        public void onSendName(Event myName) throws PageException {
		// create a Input field and set it up with the given values
		InputField myInputField = (InputField) this.getComponentByName("q");
                // read the value inside the field
                this.query = myInputField.getValue().toString();
        }
    } // end MyDynPage
} // end GoogleSearchIview
